##################################################################
#                                                                #
#         DailyObs v1.11  by   Scott E. Carroll (08/07/04)       #
#                                                                #
# Decription:  This program will compile a list of the preivious #
#              day's hourly observations and should be run after #
#              midnight local time.                              #
#                                                                #
# Rev # Date     Modification                                    #
# ----- -------- ----------------------------------------------- #
# v1.00 01/28/04 Original script.                                #
# v1.01 02/22/04 Leave peak wind blank if calm                   #
# v1.02 02/27/04 Fix rain since minight problem                  #
# v1.03 03/15/04 Changed write path for Compaq                   #
# v1.10 05/23/04 Added Nextorm data retrieval for thunder        #
# v1.11 08/07/04 Changed ob file to "download.txt"               #
#                                                                #
##################################################################                                              

use POSIX qw(ceil);

### Get System Time ###

$dst_flag = (localtime)[8];
$orig_epoch = time;
if ($dst_flag == 1) {$orig_epoch = $orig_epoch - 3600;} 

$min = (localtime($orig_epoch))[1];
$orig_epoch = $orig_epoch - ($min * 60); # RESET TO LATEST HOUR
$hhh = (localtime($orig_epoch))[2];
$orig_epoch = $orig_epoch - ($hhh * 3600); # RESET TO TODAY AT MIDNIGHT
$orig_epoch = $orig_epoch - 86400; # RESET TO YESTERDAY AT MIDNIGHT

$day = (localtime($orig_epoch))[3];
if ($day < 10) {$day = "0" . $day;}
$month = (localtime($orig_epoch))[4] + 1;
if ($month < 10) {$month = "0" . $month;}
$year = (localtime($orig_epoch))[5] + 1900;
$yr = substr($year,2,2);

$file_date = "${yr}${month}${day}";
$file_dir = "C:\\Daily_Obs\\${year}\\${month}\\";

open (DATA, "c:/WeatherLink/Arlingto/downld08.txt") || die "File not found\n";

while (<DATA>) {
    if ($_ =~ /(..)\/(..)\/(..) (..):(..)(.)  (.....)  (.....)  (.....)   (...)  (.....) (.....)   (...) ..... (.....)   (...)  .....  .....  .....  (......) (.....) (.....)/) {
    #if ($_ =~ /(\d+)\/(\d+)\/(\d+)\s+(\d+):(\d+) (\w)\s+(\d+\.\d)\s+(\d+\.\d)\s+(\d+\.\d)\s+(\d+)\s+(\d+\.\d)\s+(\d+\.\d)\s+(\w+)\s+.....\s+(.....)\s+(...)\s+.....\s+.....\s+.....\s+(......)\s+(.....)\s+(.....)/) {
      #print "hello";
      $mm = $1;
      $dd = $2;
      $yy = $3;
      $h = $4;
      $m = $5;
      $ampm = $6;
      if ($mm < 10) {$mm = "0" . $mm;}

      if (($ampm eq "p") && ($h < 12)) {$h = $h + 12;}
      if (($ampm eq "a") && ($h == 12)) {$h = 0;}
      $tmp[$dd][$h][$m] = int($7 + .5);
      $max[$dd][$h][$m] = int($8 + .5);
      $min[$dd][$h][$m] = int($9 + .5);
      $hum[$dd][$h][$m] = int($10 + .5);
      $dp[$dd][$h][$m] = int($11 + .5);
      $ws[$dd][$h][$m] = int($12 + .5);
      $wd[$dd][$h][$m] = $13;
      $gst[$dd][$h][$m] = int($14 +.5);

      ### Numerical compass point converter (used for VRB computation) ###
      if ($wd[$dd][$h][$m] eq "  N") {$wdn[$dd][$h][$m] = 0;}
      if ($wd[$dd][$h][$m] eq "NNE") {$wdn[$dd][$h][$m] = 1;}
      if ($wd[$dd][$h][$m] eq " NE") {$wdn[$dd][$h][$m] = 2;}
      if ($wd[$dd][$h][$m] eq "ENE") {$wdn[$dd][$h][$m] = 3;}
      if ($wd[$dd][$h][$m] eq "  E") {$wdn[$dd][$h][$m] = 4;}
      if ($wd[$dd][$h][$m] eq "ESE") {$wdn[$dd][$h][$m] = 5;}
      if ($wd[$dd][$h][$m] eq " SE") {$wdn[$dd][$h][$m] = 6;}
      if ($wd[$dd][$h][$m] eq "SSE") {$wdn[$dd][$h][$m] = 7;}
      if ($wd[$dd][$h][$m] eq "  S") {$wdn[$dd][$h][$m] = 8;}
      if ($wd[$dd][$h][$m] eq "SSW") {$wdn[$dd][$h][$m] = 9;}
      if ($wd[$dd][$h][$m] eq " SW") {$wdn[$dd][$h][$m] = 10;}
      if ($wd[$dd][$h][$m] eq "WSW") {$wdn[$dd][$h][$m] = 11;}
      if ($wd[$dd][$h][$m] eq "  W") {$wdn[$dd][$h][$m] = 12;}
      if ($wd[$dd][$h][$m] eq "WNW") {$wdn[$dd][$h][$m] = 13;}
      if ($wd[$dd][$h][$m] eq " NW") {$wdn[$dd][$h][$m] = 14;}
      if ($wd[$dd][$h][$m] eq "NNW") {$wdn[$dd][$h][$m] = 15;}

      ### Wind Speed Algorithm ###
      if (($ws[$dd][$h][$m] == 1) || ($ws[$dd][$h][$m] == 2)) {$ws[$dd][$h][$m] = 3;}
      if (($gst[$dd][$h][$m] == 1) || ($gst[$dd][$h][$m] == 2)) {$gst[$dd][$h][$m] = 3;}
      $ws[$dd][$h][$m] = int((($ws[$dd][$h][$m] + $ws[$dd][$h][$m] + $gst[$dd][$h][$m])/3) + .5);

      $gstd[$dd][$h][$m] = $15;
      $bar[$dd][$h][$m] = $16;
      $rain[$dd][$h][$m] = $17;
      $rate[$dd][$h][$m] = $18;
      if ($wd[$dd][$h][$m] eq "---") {$wd[$dd][$h][$m] = "";}
      if ($gstd[$dd][$h][$m] eq "---") {$gstd[$dd][$h][$m] = "";}
      $wd[$dd][$h][$m] =~s /\s+//;
      $gstd[$dd][$h][$m] =~s /\s+//;
    }
  }

close (DATA);

open (OUT, ">c:/Daily_Obs/${year}/${month}/${file_date}.txt");
if (!(-e OUT)) {
  system ("mkdir c:\\Daily_Obs\\${year}");
  system ("mkdir c:\\Daily_Obs\\${year}\\${month}");
  open (OUT, ">c:/Daily_Obs/${year}/${month}/${file_date}.txt");
}

for ($step = 0; $step <= 24; $step++) {
  $hour = $step; $hr = $step; 
  if ($hour == 24) {$hour = 0; $hr = 0;}
 
  $epoch = $orig_epoch + ($step * 3600);

  ### Set Period Start Points (hour) ###
  $hour1h = (localtime($epoch - 3600))[2]; 
  $hour3h = (localtime($epoch - 10800))[2];
  $hour15m = (localtime($epoch - 900))[2];
  $hour24h = (localtime($epoch - 86400))[2];

  ### Set Period Start Points (day) ###
  $day = (localtime($epoch))[3]; 
  $day1h = (localtime($epoch - 3600))[3]; 
  $day3h = (localtime($epoch - 10800))[3];
  $day15m = (localtime($epoch - 900))[3];
  $day24h = (localtime($epoch - 86400))[3];
  $daynext = (localtime($epoch + 86400))[3];

  ### Format Date/Time ###
  $month = (localtime($epoch))[4] + 1;
  if ($month < 10) {$month = " " . $month;}
  if ($day < 10) {$day = "0" . $day;}
  if ($hr < 12) {$ap = "a";} else {$ap = "p"; $hr=$hr - 12;}
  if ($hr == 0) {$hr = 12;} 
  if ($hr < 10) {$hr = " " . $hr;}
  $year = (localtime($epoch))[5] + 1900;
  $yr = substr($year,2,2);

  if ($step==0) {
    print OUT "-----------------------------------------------------------------------------------------------------------------------------------------------------------\n";
    print OUT "| Automated Surface Observations  | Latitude: 30 deg 22 min N | Longitude:  81 deg 34 min W | Station Elevation:    44 ft.  | Standard Time:   Eastern    |\n";
    print OUT "|---------------------------------------------------------------------------------------------------------------------------------------------------------|\n";
    print OUT "| Date: ${month}/${day}/${yr}                  | Station: Arlington Weather Observatory - Jacksonville, FL                               | ID: CW0569                  |\n";
    print OUT "-----------------------------------------------------------------------------------------------------------------------------------------------------------\n";
    print OUT "\n";  
    print OUT "-----------------------------------------------------------------------------------------------------------------------------------------------------------\n"; 
    print OUT "|  |             Hourly Observations                   ||        3-Hour       ||       24-Hour       ||                  Since Midnight                |  |\n";
    print OUT "|  |---------------------------------------------------||---------------------||---------------------||------------------------------------------------|  |\n";
    print OUT "|Hr|           |    Wind    | Peak  |        |    |    ||     Change     |    ||     Change     |    || Temp  | DewP  |  Hum  | Gust  |   Barom   |    |Hr|\n";
    print OUT "|  |-----------------------------------------|1-Hr|----||----------------|    ||----------------|    ||-------------------------------------------|Rain|  |\n";
    print OUT "|  |Tmp|DwP|Hum| Dir|Spd|Gst|Dir|Spd|Barom|Tn|Rain| Wx ||Tmp|DwP|Hum|Baro|Rain||Tmp|DwP|Hum|Baro|Rain||Max|Min|Max|Min|Max|Min|Dir|Spd| Max | Min |    |  |\n";
    print OUT "|---------------------------------------------------------------------------------------------------------------------------------------------------------|\n";
  }

  ### determine wind gust from previous 15 minute's obs ###
  $gust = $gst[$day15m][$hour15m][50];
  if ($gst[$day15m][$hour15m][55] > $gust) {$gust = $gst[$day15m][$hour15m][55];}
  if ($gst[$day][$hour][0] > $gust) {$gust = $gst[$day][$hour][0];}
  if (($gust < 10) || ($gust - $ws[$day][$hour][0] < 5)) {$gust = "";}

  ### determine pk wnd & P0000 (if 0 don't include) from previous hour's obs ###
  $peak = 0; $rain1h = 0; $n = 0; $rain_dif = 0; $rate_sum = 0;
  foreach $x (5,10,15,20,25,30,35,40,45,50,55,0) {
    if ($x == 0) {$y = $hour; $z = $day;} else {$y = $hour1h; $z = $day1h;}
    if ($gst[$z][$y][$x] > $peak) {$peak = $gst[$z][$y][$x]; $peakd = $gstd[$z][$y][$x];}
    $rain1h = $rain1h + $rain[$z][$y][$x];

    ### Next section helps determine if precip is stratiform or convective (standard deviation) ###
    if ($rate[$z][$y][$x] > 0) {
      $n++;
      $rate_seg[$n] = $rate[$z][$y][$x];
      $rate_sum = $rate_sum + $rate[$x][$y][$z]
    } 
  }

  ### Determine if shower or rain ###
  if ($n > 1) {
    $rate_ave = $rate_sum / $n; $squared_difs = 0;
    for ($pstep = 1; $pstep <= $n; $pstep++) {
      $squared_difs = $squared_difs + (($rate_seg[$pstep] - $rate_ave)**2);
    }
    $rate_st_dev = sqrt ($squared_difs / ($n - 1));
    if ($rate_st_dev > .5) {$shower = 1;} else {$shower = 0;}  ### THIS NUMBER MAY NEED TWEAKING ### was 1, now .5
  }

  $precip_type = "";
  if (($rate[$day][$hour][0] > 0) && ($rate[$day][$hour][0] < .2) && ($shower == 1)) {$precip_type = "RW-";}
  if (($rate[$day][$hour][0] >= .2) && ($rate[$day][$hour][0] < 1.1) && ($shower == 1)) {$precip_type = "RW";}
  if (($rate[$day][$hour][0] >= 1.1) && ($shower == 1)) {$precip_type = "RW+";}
  if (($rate[$day][$hour][0] > 0) && ($rate[$day][$hour][0] < .1) && ($shower == 0)) {$precip_type = "R-";}
  if (($rate[$day][$hour][0] >= .1) && ($rate[$day][$hour][0] < .5) && ($shower == 0)) {$precip_type = "R";}
  if (($rate[$day][$hour][0] >= .5) && ($shower == 0)) {$rain_int = "R+";}
  if ((($rain[$day][$hour][0] > 0) || ($rain[$day1h][$hour1h][55] > 0) || ($rain[$day1h][$hour1h][50] > 0)) && ($rate[$day][$hour][0] == 0)) {$precip_type = "L";}

  ### determine rain, MAX's & MIN's since mid ###
  $rain_since_mid = 0; $max_tmp = 0; $min_tmp = 100; $max_bar = 25; $min_bar = 32; $min_hum = 100; $max_hum = 0; $min_dp = 100; $max_dp = 0; $max_gst = 0; $max_gstd = "";
  if ($step == 24) {$z = $day24h;} else {$z = $day;}
  for ($y = 0; $y < $step; $y++) {
    foreach $x (0,5,10,15,20,25,30,35,40,45,50,55) {
      if (($y == 0) && ($x == 0)) {next;}  # added 2/27/04
      if ($max[$z][$y][$x] eq "") {next;}
      $rain_since_mid = $rain_since_mid + $rain[$z][$y][$x];
      if ($max[$z][$y][$x] > $max_tmp) {$max_tmp = $max[$z][$y][$x];}
      if ($min[$z][$y][$x] < $min_tmp) {$min_tmp = $min[$z][$y][$x];}
      if ($bar[$z][$y][$x] > $max_bar) {$max_bar = $bar[$z][$y][$x];}
      if ($bar[$z][$y][$x] < $min_bar) {$min_bar = $bar[$z][$y][$x];}
      if ($hum[$z][$y][$x] > $max_hum) {$max_hum = $hum[$z][$y][$x];}
      if ($hum[$z][$y][$x] < $min_hum) {$min_hum = $hum[$z][$y][$x];}
      if ($dp[$z][$y][$x] > $max_dp) {$max_dp = $dp[$z][$y][$x];}
      if ($dp[$z][$y][$x] < $min_dp) {$min_dp = $dp[$z][$y][$x];}
      if ($gst[$z][$y][$x] > $max_gst) {$max_gst = $gst[$z][$y][$x]; $max_gstd = $gstd[$z][$y][$x];}
    }
  }

  $rain_since_mid = $rain_since_mid + $rain[$day][$hour][0]; # switched 2/27/04
  #$rain_since_mid = $rain_since_mid + $rain[$day][0][0];  
  $rain_since_mid = (int(($rain_since_mid * 100) + .5))/100; # added on 2/2/04 to fix precision error

  if ($max[$day][$hour][0] > $max_tmp) {$max_tmp = $max[$day][$hour][0];}
  if ($min[$day][$hour][0] < $min_tmp) {$min_tmp = $min[$day][$hour][0];}
  if ($bar[$day][$hour][0] > $max_bar) {$max_bar = $bar[$day][$hour][0];}
  if ($bar[$day][$hour][0] < $min_bar) {$min_bar = $bar[$day][$hour][0];}
  if ($hum[$day][$hour][0] > $max_hum) {$max_hum = $hum[$day][$hour][0];}
  if ($hum[$day][$hour][0] < $min_hum) {$min_hum = $hum[$day][$hour][0];}
  if ($dp[$day][$hour][0] > $max_dp) {$max_dp = $dp[$day][$hour][0];}
  if ($dp[$day][$hour][0] < $min_dp) {$min_dp = $dp[$day][$hour][0];}
  if ($gst[$day][$hour][0] > $max_gst) {$max_gst = $gst[$day][$hour][0]; $max_gstd = $gstd[$day][$hour][0];}

  ### determine 24-hour running rainfall total ###
  $rain24h = 0;
  for ($j = $hour24h; $j <= 23; $j++) {
    if ($j != $hour24h) {$rain24h = $rain24h + $rain[$day24h][$j][0];}
    foreach $i (5,10,15,20,25,30,35,40,45,50,55) {$rain24h = $rain24h + $rain[$day24h][$j][$i];}
  }
  for ($j = 0; $j < $hour; $j++) {
    foreach $i (0,5,10,15,20,25,30,35,40,45,50,55) {$rain24h = $rain24h + $rain[$day][$j][$i];}
  }
  $rain24h = $rain24h + $rain[$day][$hour][0]; 
   
  ### determine 3-hour running rainfall total ###
  $rain3h = 0;
  if ($day3h != $day) {
    for ($j = $hour3h; $j <= 23; $j++) {
      if ($j != $hour3h) {$rain3h = $rain3h + $rain[$day3h][$j][0];}
      foreach $i (5,10,15,20,25,30,35,40,45,50,55) {$rain3h = $rain3h + $rain[$day3h][$j][$i];}
    }
    for ($j = 0; $j < $hour; $j++) {
      foreach $i (0,5,10,15,20,25,30,35,40,45,50,55) {$rain3h = $rain3h + $rain[$day][$j][$i];}
    }
    $rain3h = $rain3h + $rain[$day][$hour][0];    
  }
  else {
    for ($j = $hour3h; $j < $hour; $j++) {
      if ($j != $hour3h) {$rain3h = $rain3h + $rain[$day][$j][0];}
      foreach $i (5,10,15,20,25,30,35,40,45,50,55) {$rain3h = $rain3h + $rain[$day][$j][$i];}
    }
    $rain3h = $rain3h + $rain[$day][$hour][0];
  }

  ### determine PRESFF or PRESRR from previous 1 hour's obs ###
  $pres_character = "";
  $pres_change = $bar[$day][$hour][0] - $bar[$day1h][$hour1h][0];

  $pres_character = "S";
  if (($bar[$day][$hour][0] - $bar[$day3h][$hour3h][0]) >= .01) {$pres_character = "R";}
  if (($bar[$day][$hour][0] - $bar[$day3h][$hour3h][0]) <= (-.01)) {$pres_character = "F";}

  if ($pres_change >= .06) {$pres_character = "RR";}
  elsif ($pres_change >= .02) {
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][45]) >= .015) {$pres_character = "RR";}
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][30]) >= .03) {$pres_character = "RR";}
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][15]) >= .045) {$pres_character = "RR";}
  }

  if ($pres_change <= (-.06)) {$pres_character = "FR";}
  elsif ($pres_change <= (-.02)) {
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][45]) <= (-.015)) {$pres_character = "FR";}
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][30]) <= (-.03)) {$pres_character = "FR";}
    if (($bar[$day][$hour][0] - $bar[$day1h][$hour1h][15]) <= (-.045)) {$pres_character = "FR";}
  }

  ### Get current data ###
  $temp = $tmp[$day][$hour][0];
  $dew = $dp[$day][$hour][0];
  $humid = $hum[$day][$hour][0];
  $dir = $wd[$day][$hour][0];
  $spd = $ws[$day][$hour][0];
  $baro = $bar[$day][$hour][0];

  ### determine if winds are variable ###
  $vrb = 0;
  if (($spd <= 6) && ($gust eq "")) {
    for $x (45,50,55) {
      $testA = abs($wdn[$day1h][$hour1h][$x] - $wdn[$day][$hour][0]);
      $testB = abs(abs($wdn[$day1h][$hour1h][$x] - $wdn[$day][$hour][0]) - 15);
      if (($testA > 3) && ($testB > 3)) {$vrb = $vrb + 1;}
    }
  }
  if ($vrb > 1) {$dir = "VRB";}

  ### determine if winds are calm ###
  if (($spd == 1) || ($spd == 2)) {$spd = 3;}
  if ($spd == 0) {$dir = "CALM";}

  ### leave peak blank if zero ###
  if ($peak == 0) {$peak = ""; $peakd = "";}

  ### determine pressure in hundredths ###
  $pres = $bar[$day][$hour][0];
  $pres = (int(($pres * 100) + .5))/100;

  ### determine 3-hr & 24-hr changes ###
  $temp3h = $tmp[$day][$hour][0] - $tmp[$day3h][$hour3h][0];
  if ($temp3h > 0) {$temp3h = "+".$temp3h;}
  $temp24h = $tmp[$day][$hour][0] - $tmp[$day24h][$hour24h][0];
  if ($temp24h > 0) {$temp24h = "+".$temp24h;}  

  $dew3h = $dp[$day][$hour][0] - $dp[$day3h][$hour3h][0];
  if ($dew3h > 0) {$dew3h = "+".$dew3h;}
  $dew24h = $dp[$day][$hour][0] - $dp[$day24h][$hour24h][0];
  if ($dew24h > 0) {$dew24h = "+".$dew24h;}

  $humid3h = $hum[$day][$hour][0] - $hum[$day3h][$hour3h][0];
  if ($humid3h > 0) {$humid3h = "+".$humid3h;}
  $humid24h = $hum[$day][$hour][0] - $hum[$day24h][$hour24h][0];
  if ($humid24h > 0) {$humid24h = "+".$humid24h;}

  $baro3h = (ceil((($bar[$day][$hour][0] - $bar[$day3h][$hour3h][0])*100)-.5))/100;
  if ($baro3h > 0) {$baro3h = "+".$baro3h;}
  $baro3h=~s/0\./\./;
  $baro3h=~s/(\.\d)$/${1}0/;
  $baro24h = (ceil((($bar[$day][$hour][0] - $bar[$day24h][$hour24h][0])*100)-.5))/100;
  if ($baro24h > 0) {$baro24h = "+".$baro24h;}
  $baro24h=~s/0\./\./;
  $baro24h=~s/(\.\d)$/${1}0/;

  $ltg_step = $step + $dst_flag;
  if ($ltg_step > 23) {$ltg_step = $ltg_step - 24;}

  if ($ltg_step < 10) {$ltg_step = "0" . $ltg_step;}
  if ($step < 10) {$step = "0" . $step;}

  ### Get lightning data from Nexstorm ###
   
  open (LIGHTNING, "c:/Progra~1/Astrog~1/NexStorm/ltg${step}.dat");

  if ((-M LIGHTNING) > 1) {
    $thunder = "";
  }
  else {
    $strikes = 0;
    while (<LIGHTNING>) {
      if ($_ =~ /(\d+)\,(\d+)\,(\d)/) {
        $seconds = $1;
        $distance = $2;
        $type = $3;
        if (($seconds >= ((3600 * $ltg_step) - 900)) && ($seconds <= (3600 * $ltg_step)) && ($distance <= 11)) {$strikes = $strikes + 1;}
      }
    }
  }

  close (LIGHTNING);

  print "No. of strikes ${strikes}\n";

  if ($strikes >= 3) {$thunder = "T";}
  else {$thunder = ""; }
  
  if ($precip_type eq "") {$precip_type = " " . $thunder;}
  else {$precip_type = $thunder . $precip_type;}  

  #########################################
  
  if ($step == 0) {printf OUT ("|%2s|%3d|%3d|%3d|%4s|%3d|%3s|%3s|%3s|%5.2f|%2s|%3.2f|%4s||%3s|%3s|%3s|%4s|%3.2f||%3s|%3s|%3s|%4s|%3.2f||XXX|XXX|XXX|XXX|XXX|XXX|XXX|XXX|XXXXX|XXXXX|XXXX|%2s|\n", $step, $temp, $dew, $humid, $dir, $spd, $gust, $peakd, $peak, $baro, $pres_character, $rain1h, $precip_type, $temp3h, $dew3h, $humid3h, $baro3h, $rain3h, $temp24h, $dew24h, $humid24h, $baro24h, $rain24h, $step);}
  else {printf OUT ("|%2s|%3d|%3d|%3d|%4s|%3d|%3s|%3s|%3s|%5.2f|%2s|%3.2f|%4s||%3s|%3s|%3s|%4s|%3.2f||%3s|%3s|%3s|%4s|%3.2f||%3d|%3d|%3d|%3d|%3d|%3d|%3s|%3d|%5.2f|%5.2f|%3.2f|%2s|\n", $step, $temp, $dew, $humid, $dir, $spd, $gust, $peakd, $peak, $baro, $pres_character, $rain1h, $precip_type, $temp3h, $dew3h, $humid3h, $baro3h, $rain3h, $temp24h, $dew24h, $humid24h, $baro24h, $rain24h, $max_tmp, $min_tmp, $max_dp, $min_dp, $max_hum, $min_hum, $max_gstd, $max_gst, $max_bar, $min_bar, $rain_since_mid, $step);}
      
  if ($step == 24) {print OUT "-----------------------------------------------------------------------------------------------------------------------------------------------------------\n";}
  else {print OUT "|--|---|---|---|----|---|---|---|---|-----|--|----|----||---|---|---|----|----||---|---|---|----|----||---|---|---|---|---|---|---|---|-----|-----|----|--|\n";}
}

close (DATA);
close (OUT);

system "copy ${file_dir}${file_date}.txt C:\\Daily_Obs\\current.txt";

system "notepad /p c:\\Daily_Obs\\current.txt";

open (OUT, ">c:/Daily_Obs/current.html");

print OUT "<html><listing>\n";

open (IN, "c:/Daily_Obs/current.txt");

while (<IN>) {print OUT "$_<br>";}

close (IN);

print OUT "</listing></html>\n";

close (OUT);

exit;
